"""Top-level package for datools."""

__author__ = """Adam Marcus"""
__email__ = 'marcua@marcua.net'
__version__ = '0.1.4'
